@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.010006'; # VERSION
+our $VERSION = '0.010007'; # VERSION
 
 1;
 
@@ -21,7 +21,7 @@ Business::CyberSource - Perl interface to the CyberSource Simple Order SOAP API
 
 =head1 VERSION
 
-version 0.010006
+version 0.010007
 
 =head1 DESCRIPTION
 
@@ -262,6 +262,8 @@ feature.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Carl Carstenson Lantz Jonathan William Taylor Robert Stone
+
 =over 4
 
 =item *
@@ -274,6 +276,10 @@ Carl Lantz <carl.lantz@endurance.com>
 
 =item *
 
+Jonathan William Taylor <jonathan.taylor@endurance.com>
+
+=item *
+
 Robert Stone <robertstone@hostgator.com>
 
 =back
@@ -284,7 +290,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
