@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010006'; # VERSION
+our $VERSION = '0.010007'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request';
@@ -14,9 +14,20 @@ with qw(
 	Business::CyberSource::Request::Role::TaxService
 );
 
-use MooseX::Types::CyberSource qw( BusinessRules );
+use MooseX::Types::CyberSource qw( BusinessRules AuthService );
 
-has '+service' => ( remote_name => 'ccAuthService' );
+use Module::Runtime qw( use_module );
+
+has '+service' => (
+    remote_name => 'ccAuthService',
+    isa         => AuthService,
+    lazy_build  => 0,
+);
+
+sub _build_service {
+	use_module('Business::CyberSource::RequestPart::Service::Auth');
+	return Business::CyberSource::RequestPart::Service::Auth->new;
+}
 
 has business_rules => (
 	isa         => BusinessRules,
@@ -43,7 +54,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version 0.010006
+version 0.010007
 
 =head1 SYNOPSIS
 
@@ -140,7 +151,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
